@@ -63,7 +63,6 @@ class JsonApiModelViewBuilder:
                  authentication_classes: Optional[Sequence[Type[BaseAuthentication]]] = None,
                  queryset: Optional[QuerySet] = None,
                  permitted_objects: Optional[Callable[[Request, QuerySet], QuerySet]] = None,
-                 skip_plugins: Optional[Sequence[str]] = None,
                  include_plugins: Optional[Sequence[str]] = None,
                  plugin_options: Optional[Dict[str, Any]] = None):
         self.__validate_http_methods(allowed_methods)
@@ -98,13 +97,7 @@ class JsonApiModelViewBuilder:
         else:
             self._queryset = queryset
         self._spice_queryset = permitted_objects
-        self._skip_plugins = skip_plugins if skip_plugins is not None else [plugins.AUTO_ADMIN_VIEWS]
-        if plugins.AUTO_ADMIN_VIEWS not in self._skip_plugins:
-            self._skip_plugins.append(plugins.AUTO_ADMIN_VIEWS)
-        include_plugins = include_plugins or []
-        for item in include_plugins:
-            if item in self._skip_plugins:
-                self._skip_plugins.remove(item)
+        self._include_plugins = include_plugins or []
         self._plugin_options = plugin_options or {}
 
     @staticmethod
@@ -270,10 +263,8 @@ class JsonApiModelViewBuilder:
 
     def _get_history_urls(self) -> Sequence[partial]:
         history_builder = deepcopy(self)
-        if plugins.AUTO_ADMIN_VIEWS not in history_builder._skip_plugins:
-            history_builder._skip_plugins = [plugins.DJANGO_SIMPLE_HISTORY]
-        else:
-            history_builder._skip_plugins = [plugins.DJANGO_SIMPLE_HISTORY, plugins.AUTO_ADMIN_VIEWS]
+        if plugins.DJANGO_SIMPLE_HISTORY in self._include_plugins:
+            history_builder._include_plugins = []
         history_builder._model = apps.get_model(self._model.objects.model._meta.db_table.split('_')[0],
                                                 f'Historical{self._model.__name__}')
         history_builder._queryset = self._model.history
@@ -293,7 +284,8 @@ class JsonApiModelViewBuilder:
 
     def _get_admin_urls(self, ignore_swagger: bool = False) -> Sequence[partial]:
         admin_builder = deepcopy(self)
-        admin_builder._skip_plugins = [plugins.AUTO_ADMIN_VIEWS]
+        if plugins.AUTO_ADMIN_VIEWS in self._include_plugins:
+            admin_builder._include_plugins = []
         admin_builder._spice_queryset = None
         admin_builder._resource_name = f'{admin_builder._resource_name}'
         admin_permission_class = admin_builder._plugin_options.get(plugins.AUTO_ADMIN_VIEWS, {}).get(
@@ -510,7 +502,7 @@ class JsonApiModelViewBuilder:
                     name=f'{self._resource_name}{self._api_version}-relationships'),
             ])
 
-        if plugins.DJANGO_SIMPLE_HISTORY not in self._skip_plugins:
+        if plugins.DJANGO_SIMPLE_HISTORY in self._include_plugins:
             try:
                 import simple_history
 
@@ -518,7 +510,7 @@ class JsonApiModelViewBuilder:
             except Exception as e:
                 pass
 
-        if plugins.AUTO_ADMIN_VIEWS not in self._skip_plugins:
+        if plugins.AUTO_ADMIN_VIEWS in self._include_plugins:
             urls.extend(self._get_admin_urls(ignore_swagger=ignore_swagger))
 
         return urls
